@@ -65,11 +65,13 @@ class ResolverPlayground:
             "package.use",
             "package.use.force",
             "package.use.mask",
+            "package.use.stable",
             "package.use.stable.force",
             "package.use.stable.mask",
             "soname.provided",
             "use.force",
             "use.mask",
+            "use.stable",
             "layout.conf",
         )
     )
@@ -1036,6 +1038,7 @@ class ResolverPlaygroundResult:
         "forced_rebuilds",
         "required_use_unsatisfied",
         "graph_order",
+        "virtual_cycle",
     )
     optional_checks = (
         "forced_rebuilds",
@@ -1059,6 +1062,7 @@ class ResolverPlaygroundResult:
         self.unsatisfied_deps = frozenset()
         self.forced_rebuilds = None
         self.required_use_unsatisfied = None
+        self.virtual_cycle = None
 
         self.graph_order = [
             _mergelist_str(node, self.depgraph)
@@ -1137,6 +1141,9 @@ class ResolverPlaygroundResult:
         if required_use_unsatisfied:
             self.required_use_unsatisfied = set(required_use_unsatisfied)
 
+        if self.depgraph._virtual_cycle:
+            self.virtual_cycle = {pkg.cpv for pkg in self.depgraph._virtual_cycle}
+
 
 class ResolverPlaygroundDepcleanResult:
     checks = (
