@@ -8,7 +8,7 @@ from portage.exception import (
     InvalidAtom,
     PortageException,
     FileNotFound,
-    IsADirectory,
+    InvalidLocation,
     OperationNotPermitted,
     ParseError,
     PermissionDenied,
@@ -79,14 +79,6 @@ import portage
 # PREFIX LOCAL
 from portage.const import EPREFIX
 
-portage.proxy.lazyimport.lazyimport(
-    globals(),
-    "pickle",
-    "portage.dep:Atom",
-    "subprocess",
-)
-
-
 noiselimit = 0
 
 
@@ -521,6 +513,7 @@ def grabdict_package(
 ):
     """Does the same thing as grabdict except it validates keys
     with isvalidatom()"""
+    from portage.dep import Atom
 
     if recursive:
         file_list = _recursive_file_list(myfilename)
@@ -584,6 +577,8 @@ def grabfile_package(
     eapi=None,
     eapi_default="0",
 ):
+    from portage.dep import Atom
+
     pkgs = grabfile(
         myfilename, compatlevel, recursive=recursive, remember_source_file=True
     )
@@ -1052,6 +1047,8 @@ pickle_write = None
 
 
 def pickle_read(filename, default=None, debug=0):
+    import pickle
+
     if not os.access(filename, os.R_OK):
         writemsg(_("pickle_read(): File not readable. '") + filename + "'\n", 1)
         return default
@@ -1384,7 +1381,7 @@ def apply_recursive_permissions(
                 # Ignore InvalidLocation exceptions such as FileNotFound
                 # and DirectoryNotFound since sometimes things disappear,
                 # like when adjusting permissions on DISTCC_DIR.
-                if not isinstance(e, portage.exception.InvalidLocation):
+                if not isinstance(e, InvalidLocation):
                     all_applied = False
                     onerror(e)
     return all_applied
@@ -1952,6 +1949,7 @@ def find_updated_config_files(target_root, config_protect):
             [protected_file, None]
     If no configuration files needs to be updated, None is returned
     """
+    import subprocess
 
     encoding = _encodings["fs"]
 
